/**
   Programme ESP_LED.ino 
   créé le 11/03/2020 à partir de BasicHTTPSClient.ino
   https://github.com/esp8266/Arduino/blob/master/libraries/ESP8266HTTPClient/examples/BasicHttpsClient/BasicHttpsClient.ino
*/

#include <Arduino.h>

#include <ESP8266WiFi.h>
#include <ESP8266WiFiMulti.h>

#include <ESP8266HTTPClient.h>

#include <WiFiClientSecureBearSSL.h>
// Empreinte du certificat pour la démo, expire le 30/05/2020 à 03:00:49, à mettre à jour en fonction de la date
// SHA1 du certificat
// 64:43:E4:28:0B:7B:B8:F2:E6:F2:F1:74:53:DE:BF:C9:93:BC:32:D8
const uint8_t fingerprint[20] = {0x64, 0xa43, 0xe4, 0x28, 0x0b, 0x7b, 0xb8, 0xf2, 0xe6, 0xf2, 0xf1, 0x74, 0x53, 0xde, 0xbf, 0xc9, 0x93, 0xbc, 0x32, 0xd8};

ESP8266WiFiMulti WiFiMulti;

void setup() {

  // Initialiser la patte 13 en sortie
  pinMode(13, OUTPUT); 


  Serial.begin(115200);
  // Activer la ligne ci-dessous -debug- pour des infos supplémentaires
  // Par exemple l'adresse IP de connexion à la box au démarrage
  //Serial.setDebugOutput(true);
  delay(2000);
  Serial.println("\n");
  Serial.println("== Test connexion ==");
  Serial.println("--------------------");
  Serial.println(" Pilotage de LED par Internet ");

  for (uint8_t t = 4; t > 0; t--) {
    Serial.printf("[SETUP] WAIT %d...\n", t);
    Serial.flush();
    delay(1000);
  }
  const char* ssid = "Livebox-xxx";
  const char* password = "25xxxxxxxxxxxxxxxx9279";

  WiFi.mode(WIFI_STA);
  WiFiMulti.addAP("ssid", "password");
}

void loop() {
  //Serial.print("Début de boucle ... \n");
  
  // Attendre la connexion WiFi
  if ((WiFiMulti.run() == WL_CONNECTED)) {

    std::unique_ptr<BearSSL::WiFiClientSecure>client(new BearSSL::WiFiClientSecure);

    client->setFingerprint(fingerprint);

    HTTPClient https;

    Serial.print("[HTTPS] début...\n");

    if (https.begin(*client, "https://www.framboise314.fr/HTTP/light.json")) { 

      Serial.print("[HTTPS] GET...\n");
      // Démarre la connexion et envoie l'entête (header) HTTP
      int httpCode = https.GET();

      // httpCode aura une valeur négative en cas d'erreur
      if (httpCode > 0) {
        // L'entête HTTP a été envoyée et l'entête de la réponse du Serveur a été reçue
        Serial.printf("[HTTPS] GET... code: %d\n", httpCode);

        // Fichier non trouvé sur le Serveur
        if (httpCode == HTTP_CODE_OK || httpCode == HTTP_CODE_MOVED_PERMANENTLY) {
          String payload = https.getString();
          Serial.println(payload);
          int start = payload.indexOf("light\":");
          int end = payload.indexOf('\"', start + 11 );
          String positionString = "";
          for (int i= start + 9; i < end; i++)
          positionString += payload.charAt(i);
          
          // gestion de la LED
          if (positionString == "on") {
            Serial.print("LED Allumée \n");
            digitalWrite(13, HIGH);
          }
          if (positionString == "off") {
            Serial.print("LED Eteinte \n");
            digitalWrite(13, LOW);
            
          }

        }
      } else {
        Serial.printf("[HTTPS] GET... échoué, error: %s\n", https.errorToString(httpCode).c_str());
      }

      https.end();
    } else {
      Serial.printf("[HTTPS] Connexion impossible \n");
    }
  }

  Serial.println("Attendre 1s avant de lire le fichier...");
  delay(1000);
}